'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var React = require('react');

var classnames = require('classnames');

var utilsCommons = require('@highlight-ui/utils-commons');

var icon = require('@highlight-ui/icon');

var typography = require('@highlight-ui/typography');

function _interopDefaultLegacy(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    'default': e
  };
}

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */


var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

function __rest(s, e) {
  var t = {};

  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
}

function getInitials(name, fallback) {
  if (fallback === void 0) {
    fallback = '?';
  }

  if (!name || typeof name !== 'string') return fallback;
  return name.split(' ').filter(Boolean) // filter out the empty strings
  .slice(0, 2) // We take only two words of the name for the initial
  .map(function (s) {
    return s[0].toUpperCase();
  }) // Convert the first digit of those two strings to uppercase
  .join('');
}

var styles = {
  "avatarContainer": "Avatar-module__2KFwChSW__v6-2-4",
  "avatarInitials": "Avatar-module__v_3_bHdr__v6-2-4",
  "avatarImage": "Avatar-module__3u7fA1kS__v6-2-4",
  "avatarAnimated": "Avatar-module__3Da-ZGwP__v6-2-4"
};

var getFontSize = function (sizes) {
  if (sizes < 16) return 'xsmall';
  if (sizes < 18) return 'small';
  if (sizes < 20) return 'base';
  if (sizes < 22) return 'large';
  if (sizes < 28) return 'xlarge';
  if (sizes < 36) return '2xl';
  return '3xl';
};

function getAvatarChild(src, name, imageClassname, iconSize, typographyFontSize, imageAltText) {
  var initials = getInitials(name);
  if (src) return React__default["default"].createElement("img", {
    className: classnames__default["default"](styles.avatarImage, imageClassname),
    src: src,
    alt: imageAltText !== null && imageAltText !== void 0 ? imageAltText : initials
  });

  if (!name.length) {
    return React__default["default"].createElement(icon.Icon, {
      name: "user",
      type: "solid",
      size: iconSize,
      color: "icon-default"
    });
  }

  return React__default["default"].createElement(typography.Typography, {
    token: "heading-large",
    component: "span",
    className: styles.avatarInitials,
    fontSize: typographyFontSize || getFontSize(iconSize)
  }, initials);
}

function ContainerWithRef(_a, ref) {
  var children = _a.children,
      props = __rest(_a, ["children"]);

  return props.href ? React__default["default"].createElement("a", __assign({}, props, {
    ref: ref
  }), children) : React__default["default"].createElement("div", __assign({}, props, {
    ref: ref
  }), children);
}

var Container = React__default["default"].forwardRef(ContainerWithRef);

function AvatarWithRef(props, ref) {
  var _a;

  var _b = props.src,
      src = _b === void 0 ? '' : _b,
      _c = props.name,
      name = _c === void 0 ? '' : _c,
      _d = props.avatarSize,
      avatarSize = _d === void 0 ? 46 : _d,
      iconSize = props.iconSize,
      typographyFontSize = props.typographyFontSize,
      url = props.url,
      containerClassname = props.containerClassname,
      _e = props.animate,
      animate = _e === void 0 ? false : _e,
      _f = props.imageClassname,
      imageClassname = _f === void 0 ? '' : _f,
      children = props.children,
      metadata = props.metadata,
      imageAltText = props.imageAltText,
      restProps = __rest(props, ["src", "name", "avatarSize", "iconSize", "typographyFontSize", "url", "containerClassname", "animate", "imageClassname", "children", "metadata", "imageAltText"]);

  var calculatedIconSize = iconSize || (avatarSize === 46 ? 26 : 26 + (avatarSize - 46) / 2);
  return React__default["default"].createElement(Container, __assign({}, restProps, utilsCommons.parseMetadata(metadata), {
    href: url,
    style: {
      '--avatar-size': avatarSize + "px"
    },
    className: classnames__default["default"](styles.avatarContainer, (_a = {}, _a[styles.avatarAnimated] = animate, _a), containerClassname),
    ref: ref
  }), children && typeof children === 'function' ? children(function () {
    return getAvatarChild(src, name, imageClassname, calculatedIconSize, typographyFontSize, imageAltText);
  }) : getAvatarChild(src, name, imageClassname, calculatedIconSize, typographyFontSize, imageAltText));
}

AvatarWithRef.displayName = 'Avatar';
var Avatar = React__default["default"].forwardRef(AvatarWithRef);
exports.Avatar = Avatar;
//# sourceMappingURL=index.js.map
